@@ -1,4 +1,6 @@
+import difflib
 from functools import wraps
+import re
 from flask import request, Response
 from flask import abort as original_flask_abort
 from flask.views import MethodView
@@ -61,6 +63,16 @@ class Api(object):
         if code >= 500:
             self.app.logger.exception("Internal Error")
 
+        if code == 404:
+            rules = dict([(re.sub('(<.*>)', '', rule.rule), rule.rule)
+                          for rule in self.app.url_map.iter_rules()])
+            close_matches = difflib.get_close_matches(request.path, rules.keys())
+            if close_matches:
+                data['message'] += '. You have requested this URI [' + request.path + \
+                                   '] but did you mean ' + \
+                                   ' or '.join((rules[match]
+                                   for match in close_matches)) + ' ?'
+
         resp = self.make_response(data, code)
 
         if code == 401:
@@ -99,12 +111,18 @@ class Api(object):
         """
         endpoint = kwargs.get('endpoint') or resource.__name__.lower()
 
+        if endpoint in self.app.view_functions.keys():
+            previous_view_class = self.app.view_functions[endpoint].func_dict['view_class']
+            if previous_view_class != resource: # if you override with a different class the endpoint, avoid the collision by raising an exception
+                raise ValueError('This endpoint (%s) is already set to the class %s.' % (endpoint, previous_view_class.__name__))
+
         resource.mediatypes = self.mediatypes_method()  # Hacky
         resource_func = self.output(resource.as_view(endpoint))
 
         for decorator in self.decorators:
             resource_func = decorator(resource_func)
 
+
         for url in urls:
             self.app.add_url_rule(self.prefix + url, view_func=resource_func)
 
