@@ -1,4 +1,5 @@
 from flask import request
+from werkzeug.datastructures import MultiDict
 import flask_restful
 
 class Namespace(dict):
@@ -59,7 +60,7 @@ class Argument(object):
         """Pulls values off the request in the provided location
         :param request: The flask request object to parse arguments from
         """
-        return getattr(request, self.location, request.values)
+        return getattr(request, self.location, MultiDict())  # either find it or don't
 
     def convert(self, value, op):
         try:
@@ -92,11 +93,11 @@ class Argument(object):
         for operator in self.operators:
             name = self.name + operator.replace("=", "", 1)
             if name in source:
-                try:
+                # Account for MultiDict and regular dict
+                if hasattr(source, "getlist"):
                     values = source.getlist(name)
-                except:
-                    # FIXME : what is the case of that ?
-                    values = source.getall(name)
+                else:
+                    values = [source.get(name)]
 
                 for value in values:
                     if not self.case_sensitive:
@@ -116,7 +117,7 @@ class Argument(object):
 
         if not results and self.required:
             self.handle_validation_error(ValueError(
-                u"{0} is required".format(self.name)))
+                u"{0} is required in {1}".format(self.name, self.location)))
 
         if not results:
             return self.default
@@ -158,12 +159,7 @@ class RequestParser(object):
         if req is None:
             req = request
 
-        if hasattr(req, 'view_args') and req.view_args is not None:
-            self.url_matches = req.view_args
-            namespace = self.namespace_class(req.view_args.iteritems())
-        else:
-            self.url_matches = {}
-            namespace = self.namespace_class()
+        namespace = self.namespace_class()
 
         for arg in self.args:
             namespace[arg.dest or arg.name] = arg.parse(req)
